CSMR: The main function of the RBSL algorithm.

View source: R/RBSL.R

CSMRR Documentation

The main function of the RBSL algorithm.

Description

The main function of the RBSL algorithm.

Usage

CSMR(x, y, nit, nc, max_iter)

Arguments

x

The matrix

y

The external supervised variable.

nit

xxx?

nc

The component number in the mixture model.

max_iter

The maximum iteration number.

Value

A list object consist of coefficient, clustering membership, data x, external variable y, predicted y based on regression model.


RobMixReg documentation built on June 2, 2026, 9:06 a.m.