Compute_Rbase_SVD: Compute the row space using SVD.

View source: R/compute_SVD.R

Compute_Rbase_SVDR Documentation

Compute the row space using SVD.

Description

Compute the row space using SVD.

Usage

Compute_Rbase_SVD(bulk_data, tg_R1_lists_selected)

Arguments

bulk_data

The bulk data..

tg_R1_lists_selected

A list of the marker genes for several cell types.

Value

A matrix which each row span the row space using cell type specific marker genes.


RobMixReg documentation built on June 2, 2026, 9:06 a.m.