mixLp_one: mixLp_one : mixLp_one estimates the mixture regression...

View source: R/mixL.short.R

mixLp_oneR Documentation

mixLp_one : mixLp_one estimates the mixture regression parameters robustly using Laplace distribution based on one initial value.

Description

Robust mixture regression assuming that the error terms follow a Laplace distribution.

Usage

mixLp_one(formula, data, nc = 2)

Arguments

formula

A symbolic description of the model to be fit.

data

A data frame containing the predictor and response variables, where the last column is the response varible.

nc

Number of mixture components.

Value

Estimated coefficients of all components.


RobMixReg documentation built on June 2, 2026, 9:06 a.m.