mixlinrb_bione: mixlinrb_bione : mixlinrb_bione estimates the mixture...

View source: R/bi_square.short.R

mixlinrb_bioneR Documentation

mixlinrb_bione : mixlinrb_bione estimates the mixture regression parameters robustly using bisquare function based on one initial value.

Description

An EM-type of parameter estimation by replacing the least square estimation in the M-step with a robust criterior.

Usage

mixlinrb_bione(formula, data, nc = 2)

Arguments

formula

A symbolic description of the model to be fit.

data

A data frame containing the predictor and response variables, where the last column is the response varible.

nc

Number of mixture components.

Value

Estimated coefficients of all components.


RobMixReg documentation built on June 2, 2026, 9:06 a.m.